@@ -4,8 +4,12 @@ from nwon_django_toolbox.fields.pydantic_json_field import (
     PydanticJsonField,
     PydanticJsonFieldSerializer,
 )
+from nwon_django_toolbox.fields.serializer_choice_field_for_polymorphic_ctype_id import (
+    serializer_choice_field_for_polymorphic_ctype_id,
+)
 
 __all__ = [
+    "serializer_choice_field_for_polymorphic_ctype_id",
     "EncryptedTextField",
     "PydanticJsonFieldSerializer",
     "PydanticJsonField",
