@@ -17,4 +17,6 @@ __all__ = [
     "DjangoReadyEnum",
     "PydanticBaseDjango",
     "RequestBodyFormat",
+    "PermissionTestExpectation",
+    "LoginFunction",
 ]
